@@ -153,7 +153,7 @@ void     gdk_rectangle_union     (GdkRectangle *src1,
 				  GdkRectangle *src2,
 				  GdkRectangle *dest);
 
-GType gdk_rectangle_get_type (void);
+GType gdk_rectangle_get_type (void) G_GNUC_CONST;
 
 #define GDK_TYPE_RECTANGLE (gdk_rectangle_get_type ())
 
