@@ -738,6 +738,17 @@ gtk_action_sync_stock_id (GtkAction  *action,
     }
 }
 
+static void
+gtk_action_sync_button_stock_id (GtkAction  *action, 
+				 GParamSpec *pspec,
+				 GtkWidget  *proxy)
+{
+  g_object_set (G_OBJECT (proxy),
+                "stock-id",
+                action->private_data->stock_id,
+                NULL);
+}
+
 static void
 gtk_action_sync_tooltip (GtkAction  *action, 
 			 GParamSpec *pspec, 
@@ -836,7 +847,7 @@ connect_proxy (GtkAction     *action,
 			      NULL);
       
       if (GTK_IS_ACCEL_LABEL (label) && action->private_data->accel_quark)
-	g_object_set (G_OBJECT (label),
+	g_object_set (label,
 		      "accel_closure", action->private_data->accel_closure,
 		      NULL);
 
@@ -879,7 +890,7 @@ connect_proxy (GtkAction     *action,
     {
       /* toolbar item specific synchronisers ... */
 
-      g_object_set (G_OBJECT (proxy),
+      g_object_set (proxy,
 		    "visible_horizontal", action->private_data->visible_horizontal,
 		    "visible_vertical",	  action->private_data->visible_vertical,
 		    "is_important", action->private_data->is_important,
@@ -909,7 +920,7 @@ connect_proxy (GtkAction     *action,
       /* toolbar button specific synchronisers ... */
       if (GTK_IS_TOOL_BUTTON (proxy))
 	{
-	  g_object_set (G_OBJECT (proxy),
+	  g_object_set (proxy,
 			"label", action->private_data->short_label,
 			"use_underline", TRUE,
 			"stock_id", action->private_data->stock_id,
@@ -931,16 +942,30 @@ connect_proxy (GtkAction     *action,
   else if (GTK_IS_BUTTON (proxy))
     {
       /* button specific synchronisers ... */
-
-      /* synchronise the label */
-      g_object_set (G_OBJECT (proxy),
-		    "label", action->private_data->short_label,
-		    "use_underline", TRUE,
-		    NULL);
-      g_signal_connect_object (action, "notify::short-label",
-			       G_CALLBACK (gtk_action_sync_short_label),
-			       proxy, 0);
+      if (gtk_button_get_use_stock (GTK_BUTTON (proxy)))
+	{
+	  /* synchronise stock-id */
+	  g_object_set (proxy,
+			"stock-id", action->private_data->stock_id,
+			NULL);
+	  g_signal_connect_object (action, "notify::stock-id",
+				   G_CALLBACK (gtk_action_sync_button_stock_id),
+				   proxy, 0);
+	}
+      else if (GTK_IS_LABEL(GTK_BIN(proxy)->child))
+	{
+	  /* synchronise the label */
+	  g_object_set (proxy,
+			"label", action->private_data->short_label,
+			"use_underline", TRUE,
+			NULL);
+	  g_signal_connect_object (action, "notify::short-label",
+				   G_CALLBACK (gtk_action_sync_short_label),
+				   proxy, 0);
+	  
+	}
       
+      /* we leave the button alone if there is a custom child */
       g_signal_connect_object (proxy, "clicked",
 			       G_CALLBACK (gtk_action_activate), action,
 			       G_CONNECT_SWAPPED);
@@ -1398,10 +1423,12 @@ closure_accel_activate (GClosure     *closure,
                         gpointer      marshal_data)
 {
   if (gtk_action_is_sensitive (GTK_ACTION (closure->data)))
-    _gtk_action_emit_activate (GTK_ACTION (closure->data));
-
-  /* we handled the accelerator */
-  g_value_set_boolean (return_value, TRUE);
+    {
+      _gtk_action_emit_activate (GTK_ACTION (closure->data));
+      
+      /* we handled the accelerator */
+      g_value_set_boolean (return_value, TRUE);
+    }
 }
 
 static void
