@@ -23,6 +23,7 @@
 
 #include <config.h>
 
+#include "gtkalias.h"
 #include "gtkexpander.h"
 
 #include "gtklabel.h"
@@ -35,7 +36,7 @@
 
 #define GTK_EXPANDER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GTK_TYPE_EXPANDER, GtkExpanderPrivate))
 
-#define DEFAULT_EXPANDER_SIZE 12
+#define DEFAULT_EXPANDER_SIZE 10
 #define DEFAULT_EXPANDER_SPACING 2
 
 enum
@@ -45,7 +46,7 @@ enum
   PROP_LABEL,
   PROP_USE_UNDERLINE,
   PROP_USE_MARKUP,
-  PROP_PADDING,
+  PROP_SPACING,
   PROP_LABEL_WIDGET
 };
 
@@ -224,7 +225,7 @@ gtk_expander_class_init (GtkExpanderClass *klass)
 							 G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 
   g_object_class_install_property (gobject_class,
-				   PROP_PADDING,
+				   PROP_SPACING,
 				   g_param_spec_int ("spacing",
 						     P_("Spacing"),
 						     P_("Space to put between the label and the child"),
@@ -315,7 +316,7 @@ gtk_expander_set_property (GObject      *object,
     case PROP_USE_MARKUP:
       gtk_expander_set_use_markup (expander, g_value_get_boolean (value));
       break;
-    case PROP_PADDING:
+    case PROP_SPACING:
       gtk_expander_set_spacing (expander, g_value_get_int (value));
       break;
     case PROP_LABEL_WIDGET:
@@ -350,7 +351,7 @@ gtk_expander_get_property (GObject    *object,
     case PROP_USE_MARKUP:
       g_value_set_boolean (value, priv->use_markup);
       break;
-    case PROP_PADDING:
+    case PROP_SPACING:
       g_value_set_int (value, priv->spacing);
       break;
     case PROP_LABEL_WIDGET:
