@@ -32,8 +32,10 @@
  */
 
 
+#include <config.h>
 #include <glib/gprintf.h>
 #include <stdlib.h>
+#include "gtkalias.h"
 #include "gdk/gdkkeysyms.h"
 #include "gtkbutton.h"
 #include "gtkentry.h"
@@ -47,12 +49,15 @@
 #include "gtkmenu.h"
 #include "gtkmenuitem.h"
 #include "gtknotebook.h"
-#include "gtkoptionmenu.h"
 #include "gtkscrolledwindow.h"
 #include "gtkstock.h"
 #include "gtktable.h"
 #include "gtkvbox.h"
 
+#undef GTK_DISABLE_DEPRECATED
+#include "gtkoptionmenu.h"
+#define GTK_DISABLE_DEPRECATED
+
 #include "gtkintl.h"
 
 typedef struct _GtkInputDialogPrivate GtkInputDialogPrivate;
@@ -145,7 +150,7 @@ gtk_input_dialog_get_type (void)
   return input_dialog_type;
 }
 
-GtkInputDialogPrivate *
+static GtkInputDialogPrivate *
 gtk_input_dialog_get_private (GtkInputDialog *input_dialog)
 {
   GtkInputDialogPrivate *private;
@@ -236,7 +241,7 @@ gtk_input_dialog_init (GtkInputDialog *inputd)
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (inputd)->vbox), private->main_vbox,
 		      TRUE, TRUE, 0);
 
-  private->no_devices_label = gtk_label_new (_("No input devices"));
+  private->no_devices_label = gtk_label_new (_("No extended input devices"));
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (inputd)->vbox),
 		      private->no_devices_label,
 		      TRUE, TRUE, 0);
@@ -330,7 +335,7 @@ gtk_input_dialog_init (GtkInputDialog *inputd)
 
   gtk_widget_show (inputd->axis_listbox);
 
-  inputd->axis_list = 0;
+  inputd->axis_list = NULL;
 
   /* Keys listbox */
 
@@ -346,7 +351,7 @@ gtk_input_dialog_init (GtkInputDialog *inputd)
 
   gtk_widget_show (inputd->keys_listbox);
 
-  inputd->keys_list = 0;
+  inputd->keys_list = NULL;
 
   inputd->save_button = gtk_button_new_from_stock (GTK_STOCK_SAVE);
   GTK_WIDGET_SET_FLAGS (inputd->save_button, GTK_CAN_DEFAULT);
