@@ -24,6 +24,8 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
  */
 
+#include <config.h>
+#include "gtkalias.h"
 #include "gtkviewport.h"
 #include "gtkintl.h"
 #include "gtkmarshalers.h"
@@ -131,24 +133,24 @@ gtk_viewport_class_init (GtkViewportClass *class)
   g_object_class_install_property (gobject_class,
                                    PROP_HADJUSTMENT,
                                    g_param_spec_object ("hadjustment",
-							_("Horizontal adjustment"),
-							_("The GtkAdjustment that determines the values of the horizontal position for this viewport"),
+							P_("Horizontal adjustment"),
+							P_("The GtkAdjustment that determines the values of the horizontal position for this viewport"),
                                                         GTK_TYPE_ADJUSTMENT,
                                                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 
   g_object_class_install_property (gobject_class,
                                    PROP_VADJUSTMENT,
                                    g_param_spec_object ("vadjustment",
-							_("Vertical adjustment"),
-							_("The GtkAdjustment that determines the values of the vertical position for this viewport"),
+							P_("Vertical adjustment"),
+							P_("The GtkAdjustment that determines the values of the vertical position for this viewport"),
                                                         GTK_TYPE_ADJUSTMENT,
                                                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 
   g_object_class_install_property (gobject_class,
                                    PROP_SHADOW_TYPE,
                                    g_param_spec_enum ("shadow_type",
-						      _("Shadow type"),
-						      _("Determines how the shadowed box around the viewport is drawn"),
+						      P_("Shadow type"),
+						      P_("Determines how the shadowed box around the viewport is drawn"),
 						      GTK_TYPE_SHADOW_TYPE,
 						      GTK_SHADOW_IN,
 						      G_PARAM_READWRITE));
@@ -382,9 +384,15 @@ viewport_set_hadjustment_values (GtkViewport *viewport,
   GtkBin *bin = GTK_BIN (viewport);
   GtkAllocation view_allocation;
   GtkAdjustment *hadjustment = gtk_viewport_get_hadjustment (viewport);
-
+  gdouble old_page_size;
+  gdouble old_upper;
+  gdouble old_value;
+  
   viewport_get_view_allocation (viewport, &view_allocation);  
 
+  old_page_size = hadjustment->page_size;
+  old_upper = hadjustment->upper;
+  old_value = hadjustment->value;
   hadjustment->page_size = view_allocation.width;
   hadjustment->step_increment = view_allocation.width * 0.1;
   hadjustment->page_increment = view_allocation.width * 0.9;
@@ -401,7 +409,15 @@ viewport_set_hadjustment_values (GtkViewport *viewport,
   else
     hadjustment->upper = view_allocation.width;
 
-  viewport_reclamp_adjustment (hadjustment, value_changed);
+  if (gtk_widget_get_direction (GTK_WIDGET (viewport)) == GTK_TEXT_DIR_RTL) 
+    {
+      gdouble dist = old_upper - (old_value + old_page_size);
+      hadjustment->value = hadjustment->upper - dist - hadjustment->page_size;
+      viewport_reclamp_adjustment (hadjustment, value_changed);
+      *value_changed = (old_value != hadjustment->value);
+    }
+  else
+    viewport_reclamp_adjustment (hadjustment, value_changed);
 }
 
 static void
@@ -447,7 +463,8 @@ viewport_set_adjustment (GtkViewport    *viewport,
   if (!adjustment)
     adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0.0, 0.0, 0.0,
 						     0.0, 0.0, 0.0));
-
+  if (*adjustmentp)
+    g_object_unref (*adjustmentp);
   *adjustmentp = adjustment;
   g_object_ref (adjustment);
   gtk_object_sink (GTK_OBJECT (adjustment));
@@ -609,6 +626,8 @@ gtk_viewport_realize (GtkWidget *widget)
   viewport->view_window = gdk_window_new (widget->window, &attributes, attributes_mask);
   gdk_window_set_user_data (viewport->view_window, viewport);
 
+  gdk_window_set_back_pixmap (viewport->view_window, NULL, FALSE);
+  
   attributes.x = - hadjustment->value;
   attributes.y = - vadjustment->value;
   attributes.width = hadjustment->upper;
